==> jc-1.4.0.tar.gz: java/awt/TextArea__24AccessibleAWTTextArea.h <==
// public class java.awt.TextArea$AccessibleAWTTextArea

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class fc72c13fcce28ab2 java_awt_TextArea__24AccessibleAWTTextArea
// @dep_class 6e8c54c389951134 java_awt_TextComponent__24AccessibleAWTTextComponent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_TextComponent__24AccessibleAWTTextComponent

#include "java/awt/TextComponent__24AccessibleAWTTextComponent.h"

#ifndef _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_
#define _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_

// Forward structure declarations
struct _jc_java_awt_TextArea$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$refs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$refs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object	_jc_java_awt_TextArea__24AccessibleAWTTextArea$object;

typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods;
typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable;
typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype;

// Constructors
extern void _jc_java_awt_TextArea__24AccessibleAWTTextArea$method$_init$42a802c52be6527e(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *, struct _jc_java_awt_TextArea$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_TextArea__24AccessibleAWTTextArea$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_TextArea__24AccessibleAWTTextArea$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *);
};

// Vtable
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_TextComponent__24AccessibleAWTTextComponent$vmethods	java_awt_TextComponent__24AccessibleAWTTextComponent;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods	java_awt_TextArea__24AccessibleAWTTextArea;
};

// Vtype
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype {
	_jc_type			type;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs {
	struct _jc_java_awt_TextArea$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$refs {
    _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs	java_awt_TextArea__24AccessibleAWTTextArea;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_refs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_nonrefs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs	java_awt_TextArea__24AccessibleAWTTextArea;
};

// Object instance structure
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object {
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype	*vtype;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype _jc_java_awt_TextArea__24AccessibleAWTTextArea$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TextArea__24AccessibleAWTTextArea, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TextArea__24AccessibleAWTTextArea$class_object;

#endif	/* _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_ */

==> jc-1.4.5.tar.gz: java/awt/TextArea__24AccessibleAWTTextArea.h <==
// public class java.awt.TextArea$AccessibleAWTTextArea

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class fc72c13fcce28ab2 java_awt_TextArea__24AccessibleAWTTextArea
// @dep_class 620f05f6023d921c java_awt_TextComponent__24AccessibleAWTTextComponent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_TextComponent__24AccessibleAWTTextComponent

#include "java/awt/TextComponent__24AccessibleAWTTextComponent.h"

#ifndef _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_
#define _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_

// Forward structure declarations
struct _jc_java_awt_TextArea$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$refs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$refs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs	_jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs;
typedef struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object	_jc_java_awt_TextArea__24AccessibleAWTTextArea$object;

typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods;
typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable;
typedef const struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype;

// Constructors
extern void _jc_java_awt_TextArea__24AccessibleAWTTextArea$method$_init$42a802c52be6527e(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *, struct _jc_java_awt_TextArea$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_TextArea__24AccessibleAWTTextArea$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_TextArea__24AccessibleAWTTextArea$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_TextComponent__24AccessibleAWTTextComponent$vmethods	java_awt_TextComponent__24AccessibleAWTTextComponent;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vmethods	java_awt_TextArea__24AccessibleAWTTextArea;
};

// Vtype
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype {
	_jc_type			type;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs {
	struct _jc_java_awt_TextArea$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$refs {
    _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_refs	java_awt_TextArea__24AccessibleAWTTextArea;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_refs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_nonrefs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_TextArea__24AccessibleAWTTextArea$sub_nonrefs	java_awt_TextArea__24AccessibleAWTTextArea;
};

// Object instance structure
struct _jc_java_awt_TextArea__24AccessibleAWTTextArea$object {
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype	*vtype;
	_jc_java_awt_TextArea__24AccessibleAWTTextArea$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TextArea__24AccessibleAWTTextArea$vtype _jc_java_awt_TextArea__24AccessibleAWTTextArea$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TextArea__24AccessibleAWTTextArea, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TextArea__24AccessibleAWTTextArea$class_object;

#endif	/* _JC_java_awt_TextArea__24AccessibleAWTTextArea_H_ */
